@@ -25,7 +25,7 @@ Usage::
     list_task_executions_paginator: ListTaskExecutionsPaginator = client.get_paginator("list_task_executions")
     list_tasks_paginator: ListTasksPaginator = client.get_paginator("list_tasks")
 """
-from mypy_boto3_datasync.client import DataSyncClient, DataSyncClient as Client
+from mypy_boto3_datasync.client import DataSyncClient as Client, DataSyncClient
 from mypy_boto3_datasync.paginator import (
     ListAgentsPaginator,
     ListLocationsPaginator,
