@@ -21,7 +21,7 @@ Usage::
     list_tasks_paginator: ListTasksPaginator = client.get_paginator("list_tasks")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_datasync.type_defs import (
     ListAgentsResponseTypeDef,
@@ -44,64 +44,64 @@ __all__ = (
 
 class ListAgentsPaginator(Boto3Paginator):
     """
-    [Paginator.ListAgents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.6/reference/services/datasync.html#DataSync.Paginator.ListAgents)
+    [Paginator.ListAgents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.1/reference/services/datasync.html#DataSync.Paginator.ListAgents)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListAgentsResponseTypeDef, None, None]:
+    ) -> Iterator[ListAgentsResponseTypeDef]:
         """
-        [ListAgents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.6/reference/services/datasync.html#DataSync.Paginator.ListAgents.paginate)
+        [ListAgents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.1/reference/services/datasync.html#DataSync.Paginator.ListAgents.paginate)
         """
 
 
 class ListLocationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListLocations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.6/reference/services/datasync.html#DataSync.Paginator.ListLocations)
+    [Paginator.ListLocations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.1/reference/services/datasync.html#DataSync.Paginator.ListLocations)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListLocationsResponseTypeDef, None, None]:
+    ) -> Iterator[ListLocationsResponseTypeDef]:
         """
-        [ListLocations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.6/reference/services/datasync.html#DataSync.Paginator.ListLocations.paginate)
+        [ListLocations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.1/reference/services/datasync.html#DataSync.Paginator.ListLocations.paginate)
         """
 
 
 class ListTagsForResourcePaginator(Boto3Paginator):
     """
-    [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.6/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
+    [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.1/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
     """
 
     def paginate(
         self, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListTagsForResourceResponseTypeDef, None, None]:
+    ) -> Iterator[ListTagsForResourceResponseTypeDef]:
         """
-        [ListTagsForResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.6/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource.paginate)
+        [ListTagsForResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.1/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource.paginate)
         """
 
 
 class ListTaskExecutionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListTaskExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.6/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
+    [Paginator.ListTaskExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.1/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
     """
 
     def paginate(
         self, TaskArn: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListTaskExecutionsResponseTypeDef, None, None]:
+    ) -> Iterator[ListTaskExecutionsResponseTypeDef]:
         """
-        [ListTaskExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.6/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions.paginate)
+        [ListTaskExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.1/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions.paginate)
         """
 
 
 class ListTasksPaginator(Boto3Paginator):
     """
-    [Paginator.ListTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.6/reference/services/datasync.html#DataSync.Paginator.ListTasks)
+    [Paginator.ListTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.1/reference/services/datasync.html#DataSync.Paginator.ListTasks)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListTasksResponseTypeDef, None, None]:
+    ) -> Iterator[ListTasksResponseTypeDef]:
         """
-        [ListTasks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.6/reference/services/datasync.html#DataSync.Paginator.ListTasks.paginate)
+        [ListTasks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.1/reference/services/datasync.html#DataSync.Paginator.ListTasks.paginate)
         """
